.. image:: https://travis-ci.org/asphalt-framework/asphalt-templating.svg?branch=master
  :target: https://travis-ci.org/asphalt-framework/asphalt-templating
  :alt: Build Status
.. image:: https://coveralls.io/repos/github/asphalt-framework/asphalt-templating/badge.svg?branch=master
  :target: https://coveralls.io/github/asphalt-framework/asphalt-templating?branch=master
  :alt: Code Coverage

This Asphalt framework component provides a standardized interface for a number of different
templating renderers:

* Django_
* Jinja2_
* Mako_
* Tonnikala_
* Tornado_

Additional backends may be provided through third party plugins.

.. _Django: https://docs.djangoproject.com/en/stable/topics/templates/
.. _Jinja2: http://jinja.pocoo.org/
.. _Mako: http://www.makotemplates.org/
.. _Tonnikala: https://github.com/ztane/Tonnikala
.. _Tornado: http://www.tornadoweb.org/en/stable/template.html

Project links
-------------

* `Documentation <http://asphalt-templating.readthedocs.org/>`_
* `Help and support <https://github.com/asphalt-framework/asphalt/wiki/Help-and-support>`_
* `Source code <https://github.com/asphalt-framework/asphalt-templating>`_
* `Issue tracker <https://github.com/asphalt-framework/asphalt-templating/issues>`_
